BoolQ is a question answering dataset for yes/no questions containing 15942
examples. These questions are naturally occurring, they are generated in
unprompted and unconstrained settings.

Each example is a triplet of (question, passage, answer), with the title of the
page as optional additional context. The text-pair classification setup is
similar to existing natural language inference tasks.
